<!--
© 2017-2019, ETH Zurich, Institut für Theoretische Physik
Author: Dominik Gresch <greschd@gmx.ch>
-->


Utilities for creating, comparing and plotting bandstructures of materials.

Documentation: http://z2pack.ethz.ch/bands-inspect

[![Build Status](https://travis-ci.org/Z2PackDev/bands_inspect.svg?branch=master)](https://travis-ci.org/Z2PackDev/bands_inspect)
